==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridSelectionRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSelectionRangeDescription } from "./WebGridSelectionRangeDescription";
/**
 * @hidden
 */
var WebGridSelectionRangeDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridSelectionRangeDescriptionMetadata, _super);
    function WebGridSelectionRangeDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridSelectionRangeDescriptionMetadata.b = function (a) {
        if (WebGridSelectionRangeDescriptionMetadata.a == null) {
            WebGridSelectionRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridSelectionRangeDescriptionMetadata.c(WebGridSelectionRangeDescriptionMetadata.a);
        }
        if (a.j(WebGridSelectionRangeDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridSelectionRangeDescriptionMetadata.a);
    };
    WebGridSelectionRangeDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridSelectionRange");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("RowStart", "Number:double");
        a.item("RowEnd", "Number:double");
        a.item("ColumnStart", "String");
        a.item("ColumnEnd", "String");
    };
    WebGridSelectionRangeDescriptionMetadata.d = function (a) {
        WebGridSelectionRangeDescriptionMetadata.b(a);
        a.aa("WebGridSelectionRange", function () { return new WebGridSelectionRangeDescription(); });
        a.z("WebGridSelectionRange", WebGridSelectionRangeDescriptionMetadata.a);
    };
    WebGridSelectionRangeDescriptionMetadata.$t = markType(WebGridSelectionRangeDescriptionMetadata, 'WebGridSelectionRangeDescriptionMetadata');
    WebGridSelectionRangeDescriptionMetadata.a = null;
    return WebGridSelectionRangeDescriptionMetadata;
}(Base));
export { WebGridSelectionRangeDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridSelectionRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSelectionRangeDescription } from "./WebGridSelectionRangeDescription";
/**
 * @hidden
 */
var WebGridSelectionRangeDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridSelectionRangeDescriptionMetadata, _super);
    function WebGridSelectionRangeDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridSelectionRangeDescriptionMetadata.b = function (a) {
        if (WebGridSelectionRangeDescriptionMetadata.a == null) {
            WebGridSelectionRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridSelectionRangeDescriptionMetadata.c(WebGridSelectionRangeDescriptionMetadata.a);
        }
        if (a.k(WebGridSelectionRangeDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridSelectionRangeDescriptionMetadata.a);
    };
    WebGridSelectionRangeDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridSelectionRange");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("RowStart", "Number:double");
        a.item("RowEnd", "Number:double");
        a.item("ColumnStart", "String");
        a.item("ColumnEnd", "String");
    };
    WebGridSelectionRangeDescriptionMetadata.d = function (a) {
        WebGridSelectionRangeDescriptionMetadata.b(a);
        a.ac("WebGridSelectionRange", function () { return new WebGridSelectionRangeDescription(); });
        a.ab("WebGridSelectionRange", WebGridSelectionRangeDescriptionMetadata.a);
    };
    WebGridSelectionRangeDescriptionMetadata.$t = markType(WebGridSelectionRangeDescriptionMetadata, 'WebGridSelectionRangeDescriptionMetadata');
    WebGridSelectionRangeDescriptionMetadata.a = null;
    return WebGridSelectionRangeDescriptionMetadata;
}(Base));
export { WebGridSelectionRangeDescriptionMetadata };
